| read.arff | R Documentation |
Reads a dataset from an ARFF file, parsing each section and
converting the data section into a data.frame.
read.arff(file, stringsAsFactors = FALSE)
file |
Name of the file to read the data from |
stringsAsFactors |
Logical: should string attributes be converted to factors? (nominal attributes are always converted to factors) |
A data.frame with some attributes:
attributes: a named vector indicating the type of each variable
relation: the original @relation of the dataset
Use attr.names(), attr.types() and relation() to consult attribute
names, types and the name of the dataset, respectively.
library(yarr)
yeast <- read.arff("yeast.arff")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.